#include <vector>
#include <algorithm>
#include <cstdio>

using namespace std;

struct MinTree {
private:
	vector <int> tree;
	void update(int t)
	{
		tree[t] = min(tree[2 * t], tree[2 * t + 1]);
	}
public:
	static const int INF = 1 << 30;

	MinTree (int size)
	{
		size += 10;

		tree = vector<int>(size, INF);
	}
	void modify(int t, int value)
	{
		tree[t] = value;
	}
	int getMin(int l, int r)
	{
		int ans = INF;
		for (int i = l; i <= r; ++i)
			ans = min(ans, tree[i]);
		return ans;
	}
};

struct Segment {
	int l, r;

	Segment(int _l, int _r) : l(_l), r(_r) {}

	bool operator <= (const Segment & s) const
	{
		return s.l <= l && r <= s.r;
	}
};

int n;
std::vector <Segment> seg;

struct Event {
	bool open;
	int num;
	int x;

	Event (bool _open, int _num, int _x) : open(_open), num(_num), x(_x) {}

	bool operator < (const Event & e) const
	{
		if (x != e.x)
			return x < e.x;

		if (open != e.open)
			return open > e.open;

		if (open)
			return seg[num].r > seg[e.num].r;
		else
			return seg[num].l > seg[e.num].l;
	}

	void print()
	{
		printf("x = %d num = %d open = %d\n", x, num, int(open));
	}
};

struct Answer {
	int * ans;
	bool * correct;

	Answer(int * ans, bool * correct)
	{
		this -> ans = ans;
		this -> correct = correct;
	}

	int getAns(int num)
	{
		return ans[num];
	}

	void setCorrect(int num, bool value)
	{
		correct[num] = value;
	}
};

struct List {
private:
	struct ListElement {
		int num;
		int prev, next;
	};


	vector <ListElement> list;
	int used;
	int fake;
	vector <int> numInList;

public:

	List (int size)
	{
		++size;
		list.resize(size);
		numInList.resize(size);

		used = 0;
		fake = used++;

		list[fake].next = list[fake].prev = fake;
	}

	void insertBehind(int next, int num)
	{
		int prev = list[next].prev;

		list[prev].next = num;
		list[next].prev = num;

		list[num].next = next;
		list[num].prev = prev;
	}

	void deleteElement(int num)
	{
		int prev = list[num].prev;
		int next = list[num].next;

		list[prev].next = next;
		list[next].prev = prev;
	}

	int newElement(int num)
	{
		int cur = used++;
		list[cur].num = num;
		numInList[num] = cur;
		list[cur].next = list[cur].prev = -1;
		return cur;
	}

	void insertAtEnd(int num)
	{
		insertBehind(fake, num);
	}

	int getPrev(int num) const
	{
		return list[num].prev;
	}

	int getNumInList(int num) const
	{
		return numInList[num];
	}

	int getFake() const
	{
		return fake;
	}
};

const int N = 128 * 1024;

int pans[N], jans[N];
bool pCorrect[N], jCorrect[N];

void solve()
{
	MinTree minTree(n);
	List list(n);

	vector <Answer> answers;
	answers.push_back(Answer(pans, pCorrect));
	answers.push_back(Answer(jans, jCorrect));

	vector <Event> events;

	for (int i = 0; i < n; ++i)
	{
		events.push_back(Event(true, i, seg[i].l));
		events.push_back(Event(false, i, seg[i].r));
	}

	sort(events.begin(), events.end());

	for (int i = 0; i < int(events.size()); ++i)
	{
		int num = events[i].num;

		if (events[i].open)
		{
			int curNum = list.newElement(num);
			minTree.modify(curNum, seg[num].r);
			list.insertAtEnd(curNum);
		}
		else
		{
			int cur, prev;
			cur = list.getNumInList(num);
			prev = list.getPrev(cur);

			for (int j = 0; j < int(answers.size()); ++j)
			{
				int ans = answers[j].getAns(num);

				if (prev == list.getFake())
					answers[j].setCorrect(num, ans == -1);
				else
				{
					if (ans == -1 || !(seg[num] <= seg[ans]) || ans == num)
						answers[j].setCorrect(num, false);
					else
					{
						int rightAns = seg[ans].r;
						int minRight = minTree.getMin(list.getNumInList(ans) + 1, cur - 1);

						answers[j].setCorrect(num, minRight > rightAns);
					}
				}
			}

			minTree.modify(cur, minTree.INF);
			list.deleteElement(cur);
		}
	}
}

void read()
{
	scanf("%d", &n);

	seg.reserve(n);

	for (int i = 0; i < n; ++i)
	{
		int l, r;
		scanf("%d %d", &l, &r);

		seg.push_back(Segment(l, r));
	}

	for (int i = 0; i < n; ++i)
	{
		scanf("%d", &pans[i]);
		--pans[i];
	}
	for (int i = 0; i < n; ++i)
	{	
		scanf("%d", &jans[i]);
		--jans[i];
	}
}

void write()
{
	for (int i = 0; i < n; ++i)
	{
		if (!jCorrect[i])
		{
			fprintf(stderr, "#%d is wrong!\n", i);
			throw 42;
		}

		if (pCorrect[i])
			printf("OK\n");
		else
			printf("WA\n");
	}
}

int main(int argc, char *argv[])
{
	freopen("segcheck.in", "r", stdin);
	freopen("segcheck.out", "w", stdout);

	read();
	solve();
	write();

	return 0;
}